@@ -1,7 +1,4 @@
 import random
-import logging
-
-logger = logging.getLogger(__name__)
 
 
 class DynamicBackground():
@@ -24,8 +21,9 @@ class DynamicBackground():
 
 
 # Returns an array with 3 integers in range of 0-255
-#The sum of the three integers will be lower than 255*2 (510) to avoid very bright colors
-#White text should be seen ok with this background color
+# The sum of the three integers will be lower than 255*2
+# (510) to avoid very bright colors
+# White text should be seen ok with this background color
 
 
 def get_valid_color():
@@ -38,4 +36,4 @@ def get_valid_color():
     if extra > 0:
         i = random.randint(0, 2)
         color[i] -= extra
-    return color
+    return color
\ No newline at end of file
