@@ -1,18 +1,19 @@
 from .list_view import ListView
+from .base_screen import BaseScreen
 
 
-class PlaylistScreen():
-    def __init__(self, size, base_size, manager):
-        self.size = size
-        self.base_size = base_size
-        self.manager = manager
-        self.list_view = ListView((0, self.base_size), (self.size[0], self.size[1] - 2 * self.base_size),
-                                  self.base_size, manager.fonts['base'])
+class PlaylistScreen(BaseScreen):
+    def __init__(self, size, base_size, manager, fonts):
+        BaseScreen.__init__(self, size, base_size, manager, fonts)
+        self.list_view = ListView((0, 0), (
+            self.size[0], self.size[1] - self.base_size),
+                                  self.base_size,
+                                  self.fonts['base'])
         self.playlists_strings = []
         self.playlists = []
         self.playlists_loaded()
 
-    def update(self, screen):
+    def update(self, screen, update_all):
         self.list_view.render(screen)
 
     def playlists_loaded(self):
@@ -27,5 +28,6 @@ class PlaylistScreen():
         clicked = self.list_view.touch_event(touch_event)
         if clicked is not None:
             self.manager.core.tracklist.clear()
-            self.manager.core.tracklist.add(uri=self.playlists[clicked].uri)
+            self.manager.core.tracklist.add(
+                uri=self.playlists[clicked].uri)
             self.manager.core.playback.play()
